==> joounit-0.9.5.jar: joo/classes/flexunit/runner/BaseTestRunner.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.runner",/*
{

   import flexunit.framework.*;*/

   "public class BaseTestRunner implements flexunit.framework.TestListener",1,function($$private){;return[
   

      "public function startTest",function startTest( test/*:Test*/ )/*:void*/
      {
         this.testStarted( test );
      },

   //------------------------------------------------------------------------------

      "public function endTest",function endTest( test/*:Test*/ )/*:void*/
      {
         this.testEnded( test );
      },

   //------------------------------------------------------------------------------

      "public function addError",function addError( test/*:Test*/, error/*:Error*/ )/*:void*/
      {
         this.testError( test, error );
      },

   //------------------------------------------------------------------------------

      "public function addFailure",function addFailure( test/*:Test*/, error/*:AssertionFailedError*/ )/*:void*/
      {
         this.testFailure( test, error );
      },

   //------------------------------------------------------------------------------

      "public function testStarted",function testStarted( test/* : Test*/ )/* : void*/ {},

      "public function testEnded",function testEnded( test/* : Test*/ )/* : void*/ {},

      "public function testError",function testError( test/* : Test*/, error/* : Error*/ )/* : void*/ {},

      "public function testFailure",function testFailure( test/* : Test*/, error/* : AssertionFailedError*/ )/* : void*/ {},
   ];},[],["flexunit.framework.TestListener"], "0.8.0", "0.9.5"
);

==> joounit-1.0.0.jar: joo/classes/flexunit/runner/BaseTestRunner.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.runner",/*
{

   import flexunit.framework.*;*/

   "public class BaseTestRunner implements flexunit.framework.TestListener",1,function($$private){return[
   

      "public function startTest",function startTest( test/*:Test*/ )/*:void*/
      {
         this.testStarted( test );
      },

   //------------------------------------------------------------------------------

      "public function endTest",function endTest( test/*:Test*/ )/*:void*/
      {
         this.testEnded( test );
      },

   //------------------------------------------------------------------------------

      "public function addError",function addError( test/*:Test*/, error/*:Error*/ )/*:void*/
      {
         this.testError( test, error );
      },

   //------------------------------------------------------------------------------

      "public function addFailure",function addFailure( test/*:Test*/, error/*:AssertionFailedError*/ )/*:void*/
      {
         this.testFailure( test, error );
      },

   //------------------------------------------------------------------------------

      "public function testStarted",function testStarted( test/* : Test*/ )/* : void*/ {},

      "public function testEnded",function testEnded( test/* : Test*/ )/* : void*/ {},

      "public function testError",function testError( test/* : Test*/, error/* : Error*/ )/* : void*/ {},

      "public function testFailure",function testFailure( test/* : Test*/, error/* : AssertionFailedError*/ )/* : void*/ {},
   undefined];},[],["flexunit.framework.TestListener"], "0.8.0", "1.0.0"
);
